Language configuration module for Pascal.
Pascal Language
This module provides pascal language functionality for the Oaks project.
Structs
- Pascal
Language - Implementation of the Pascal language.
Language configuration module for Pascal.
This module provides pascal language functionality for the Oaks project.