PascalTokenType

Enum PascalTokenType 

pub enum PascalTokenType {
Show 75 variants Whitespace, Newline, Comment, Program, Begin, End, Var, Const, Type, Function, Procedure, If, Then, Else, While, Do, For, To, Downto, Repeat, Until, Case, Of, With, Record, Array, Set, File, Packed, Nil, True, False, And, Or, Not, Div, Mod, In, Identifier, IntegerLiteral, RealLiteral, StringLiteral, CharLiteral, Plus, Minus, Multiply, Divide, Assign, Equal, NotEqual, Less, LessEqual, Greater, GreaterEqual, LeftParen, RightParen, LeftBracket, RightBracket, Semicolon, Comma, Dot, Colon, Range, Caret, Root, ProgramBlock, VarSection, ConstSection, TypeSection, ProcedureDef, FunctionDef, CompoundStmt, Expression, Error, Eof,
}
Token types for Pascal.

Variants



Whitespace

Whitespace characters.



Newline

Newline characters.



Comment

Comments.



Program

program keyword.



Begin

begin keyword.



End

end keyword.



Var

var keyword.



Const

const keyword.



Type

type keyword.



Function

function keyword.



Procedure

procedure keyword.



If

if keyword.



Then

then keyword.



Else

else keyword.



While

while keyword.



Do

do keyword.



For

for keyword.



To

to keyword.



Downto

downto keyword.



Repeat

repeat keyword.



Until

until keyword.



Case

case keyword.



Of

of keyword.



With

with keyword.



Record

record keyword.



Array

array keyword.



Set

set keyword.



File

file keyword.



Packed

packed keyword.



Nil

nil keyword.



True

true keyword.



False

false keyword.



And

and keyword.



Or

or keyword.



Not

not keyword.



Div

div keyword.



Mod

mod keyword.



In

in keyword.



Identifier

An identifier.



IntegerLiteral

An integer literal.



RealLiteral

A real number literal.



StringLiteral

A string literal.



CharLiteral

A character literal.



Plus

Plus operator +.



Minus

Minus operator -.



Multiply

Multiply operator *.



Divide

Divide operator /.



Assign

Assignment operator :=.



Equal

Equality operator =.



NotEqual

Inequality operator <>.



Less

Less than operator <.



LessEqual

Less than or equal operator <=.



Greater

Greater than operator >.



GreaterEqual

Greater than or equal operator >=.



LeftParen

Left parenthesis (.



RightParen

Right parenthesis ).



LeftBracket

Left bracket [.



RightBracket

Right bracket ].



Semicolon

Semicolon ;.



Comma

Comma ,.



Dot

Dot ..



Colon

Colon :.



Range

Range operator ...



Caret

Caret operator ^.



Root

Root node (Internal use).



ProgramBlock

Program block (Internal use).



VarSection

Variable section (Internal use).



ConstSection

Constant section (Internal use).



TypeSection

Type section (Internal use).



ProcedureDef

Procedure definition (Internal use).



FunctionDef

Function definition (Internal use).



CompoundStmt

Compound statement (Internal use).



Expression

Expression (Internal use).



Error

Error token.



Eof

End of file.